@@ -66,6 +66,32 @@ def OxmlElement(nsptag_str, attrs=None, nsdecls=None):
 
 from .shared import CT_DecimalNumber, CT_OnOff, CT_String
 
+
+from .parts.coreprops import CT_CoreProperties
+register_element_cls('cp:coreProperties', CT_CoreProperties)
+
+from .parts.document import CT_Body, CT_Document
+register_element_cls('w:body',     CT_Body)
+register_element_cls('w:document', CT_Document)
+
+from .parts.numbering import (
+    CT_Num, CT_Numbering, CT_NumLvl, CT_NumPr
+)
+register_element_cls('w:abstractNumId', CT_DecimalNumber)
+register_element_cls('w:ilvl',          CT_DecimalNumber)
+register_element_cls('w:lvlOverride',   CT_NumLvl)
+register_element_cls('w:num',           CT_Num)
+register_element_cls('w:numId',         CT_DecimalNumber)
+register_element_cls('w:numPr',         CT_NumPr)
+register_element_cls('w:numbering',     CT_Numbering)
+register_element_cls('w:startOverride', CT_DecimalNumber)
+
+from .section import CT_PageMar, CT_PageSz, CT_SectPr, CT_SectType
+register_element_cls('w:pgMar',  CT_PageMar)
+register_element_cls('w:pgSz',   CT_PageSz)
+register_element_cls('w:sectPr', CT_SectPr)
+register_element_cls('w:type',   CT_SectType)
+
 from .shape import (
     CT_Blip, CT_BlipFillProperties, CT_GraphicalObject,
     CT_GraphicalObjectData, CT_Inline, CT_NonVisualDrawingProps, CT_Picture,
@@ -87,35 +113,19 @@ register_element_cls('wp:docPr',      CT_NonVisualDrawingProps)
 register_element_cls('wp:extent',     CT_PositiveSize2D)
 register_element_cls('wp:inline',     CT_Inline)
 
-
-from .parts.coreprops import CT_CoreProperties
-register_element_cls('cp:coreProperties', CT_CoreProperties)
-
-from .parts.document import CT_Body, CT_Document
-register_element_cls('w:body',     CT_Body)
-register_element_cls('w:document', CT_Document)
-
-from .parts.numbering import (
-    CT_Num, CT_Numbering, CT_NumLvl, CT_NumPr
-)
-register_element_cls('w:abstractNumId', CT_DecimalNumber)
-register_element_cls('w:ilvl',          CT_DecimalNumber)
-register_element_cls('w:lvlOverride',   CT_NumLvl)
-register_element_cls('w:num',           CT_Num)
-register_element_cls('w:numId',         CT_DecimalNumber)
-register_element_cls('w:numPr',         CT_NumPr)
-register_element_cls('w:numbering',     CT_Numbering)
-register_element_cls('w:startOverride', CT_DecimalNumber)
-
-from .parts.styles import CT_Style, CT_Styles
-register_element_cls('w:style',  CT_Style)
-register_element_cls('w:styles', CT_Styles)
-
-from .section import CT_PageMar, CT_PageSz, CT_SectPr, CT_SectType
-register_element_cls('w:pgMar',  CT_PageMar)
-register_element_cls('w:pgSz',   CT_PageSz)
-register_element_cls('w:sectPr', CT_SectPr)
-register_element_cls('w:type',   CT_SectType)
+from .styles import CT_LatentStyles, CT_LsdException, CT_Style, CT_Styles
+register_element_cls('w:basedOn',        CT_String)
+register_element_cls('w:latentStyles',   CT_LatentStyles)
+register_element_cls('w:locked',         CT_OnOff)
+register_element_cls('w:lsdException',   CT_LsdException)
+register_element_cls('w:name',           CT_String)
+register_element_cls('w:next',           CT_String)
+register_element_cls('w:qFormat',        CT_OnOff)
+register_element_cls('w:semiHidden',     CT_OnOff)
+register_element_cls('w:style',          CT_Style)
+register_element_cls('w:styles',         CT_Styles)
+register_element_cls('w:uiPriority',     CT_DecimalNumber)
+register_element_cls('w:unhideWhenUsed', CT_OnOff)
 
 from .table import (
     CT_Row, CT_Tbl, CT_TblGrid, CT_TblGridCol, CT_TblLayoutType, CT_TblPr,
@@ -134,8 +144,21 @@ register_element_cls('w:tcW',       CT_TblWidth)
 register_element_cls('w:tr',        CT_Row)
 register_element_cls('w:vMerge',    CT_VMerge)
 
-from .text import (
-    CT_Br, CT_Jc, CT_P, CT_PPr, CT_R, CT_RPr, CT_Text, CT_Underline
+from .text.paragraph import CT_Ind, CT_Jc, CT_P, CT_PPr, CT_Spacing
+register_element_cls('w:ind',             CT_Ind)
+register_element_cls('w:jc',              CT_Jc)
+register_element_cls('w:keepLines',       CT_OnOff)
+register_element_cls('w:keepNext',        CT_OnOff)
+register_element_cls('w:p',               CT_P)
+register_element_cls('w:pageBreakBefore', CT_OnOff)
+register_element_cls('w:pPr',             CT_PPr)
+register_element_cls('w:pStyle',          CT_String)
+register_element_cls('w:spacing',         CT_Spacing)
+register_element_cls('w:widowControl',    CT_OnOff)
+
+from .text.run import (
+    CT_Br, CT_Fonts, CT_HpsMeasure, CT_R, CT_RPr, CT_Text, CT_Underline,
+    CT_VerticalAlignRun
 )
 register_element_cls('w:b',          CT_OnOff)
 register_element_cls('w:bCs',        CT_OnOff)
@@ -147,14 +170,11 @@ register_element_cls('w:emboss',     CT_OnOff)
 register_element_cls('w:i',          CT_OnOff)
 register_element_cls('w:iCs',        CT_OnOff)
 register_element_cls('w:imprint',    CT_OnOff)
-register_element_cls('w:jc',         CT_Jc)
 register_element_cls('w:noProof',    CT_OnOff)
 register_element_cls('w:oMath',      CT_OnOff)
 register_element_cls('w:outline',    CT_OnOff)
-register_element_cls('w:p',          CT_P)
-register_element_cls('w:pPr',        CT_PPr)
-register_element_cls('w:pStyle',     CT_String)
 register_element_cls('w:r',          CT_R)
+register_element_cls('w:rFonts',     CT_Fonts)
 register_element_cls('w:rPr',        CT_RPr)
 register_element_cls('w:rStyle',     CT_String)
 register_element_cls('w:rtl',        CT_OnOff)
@@ -163,7 +183,9 @@ register_element_cls('w:smallCaps',  CT_OnOff)
 register_element_cls('w:snapToGrid', CT_OnOff)
 register_element_cls('w:specVanish', CT_OnOff)
 register_element_cls('w:strike',     CT_OnOff)
+register_element_cls('w:sz',         CT_HpsMeasure)
 register_element_cls('w:t',          CT_Text)
 register_element_cls('w:u',          CT_Underline)
 register_element_cls('w:vanish',     CT_OnOff)
+register_element_cls('w:vertAlign',  CT_VerticalAlignRun)
 register_element_cls('w:webHidden',  CT_OnOff)
