@@ -17,11 +17,12 @@ from docx.opc.coreprops import CoreProperties
 from docx.package import Package
 from docx.parts.document import DocumentPart, InlineShapes
 from docx.parts.numbering import NumberingPart
-from docx.parts.styles import StylesPart
 from docx.section import Section
 from docx.shape import InlineShape
+from docx.styles.styles import Styles
 from docx.table import Table
-from docx.text import Paragraph, Run
+from docx.text.paragraph import Paragraph
+from docx.text.run import Run
 
 from .unitutil.mock import (
     instance_mock, class_mock, method_mock, property_mock, var_mock
@@ -132,11 +133,16 @@ class DescribeDocument(object):
         document.save(file_)
         package_.save.assert_called_once_with(file_)
 
-    def it_provides_access_to_the_core_properties(self, core_props_fixture):
+    def it_provides_access_to_its_core_properties(self, core_props_fixture):
         document, core_properties_ = core_props_fixture
         core_properties = document.core_properties
         assert core_properties is core_properties_
 
+    def it_provides_access_to_its_styles(self, styles_fixture):
+        document, styles_ = styles_fixture
+        styles = document.styles
+        assert styles is styles_
+
     def it_provides_access_to_the_numbering_part(self, num_part_get_fixture):
         document, document_part_, numbering_part_ = num_part_get_fixture
         numbering_part = document.numbering_part
@@ -155,24 +161,6 @@ class DescribeDocument(object):
         )
         assert numbering_part is numbering_part_
 
-    def it_provides_access_to_the_styles_part(self, styles_part_get_fixture):
-        document, document_part_, styles_part_ = styles_part_get_fixture
-        styles_part = document.styles_part
-        document_part_.part_related_by.assert_called_once_with(RT.STYLES)
-        assert styles_part is styles_part_
-
-    def it_creates_styles_part_on_first_access_if_not_present(
-            self, styles_part_create_fixture):
-        document, StylesPart_, document_part_, styles_part_ = (
-            styles_part_create_fixture
-        )
-        styles_part = document.styles_part
-        StylesPart_.new.assert_called_once_with()
-        document_part_.relate_to.assert_called_once_with(
-            styles_part_, RT.STYLES
-        )
-        assert styles_part is styles_part_
-
     # fixtures -------------------------------------------------------
 
     @pytest.fixture(params=[
@@ -203,7 +191,7 @@ class DescribeDocument(object):
         document = Document()
         image_path_ = instance_mock(request, str, name='image_path_')
         width, height = 100, 200
-        class_mock(request, 'docx.text.Run', return_value=run_)
+        class_mock(request, 'docx.text.paragraph.Run', return_value=run_)
         run_.add_picture.return_value = picture_
         return (document, image_path_, width, height, run_, picture_)
 
@@ -248,6 +236,11 @@ class DescribeDocument(object):
         document = Document()
         return document, package_, file_
 
+    @pytest.fixture
+    def styles_fixture(self, document, styles_):
+        document._document_part.styles = styles_
+        return document, styles_
+
     @pytest.fixture
     def tables_fixture(self, document, tables_):
         return document, tables_
@@ -362,25 +355,8 @@ class DescribeDocument(object):
         return instance_mock(request, int)
 
     @pytest.fixture
-    def StylesPart_(self, request, styles_part_):
-        StylesPart_ = class_mock(request, 'docx.api.StylesPart')
-        StylesPart_.new.return_value = styles_part_
-        return StylesPart_
-
-    @pytest.fixture
-    def styles_part_(self, request):
-        return instance_mock(request, StylesPart)
-
-    @pytest.fixture
-    def styles_part_create_fixture(
-            self, document, StylesPart_, document_part_, styles_part_):
-        document_part_.part_related_by.side_effect = KeyError
-        return document, StylesPart_, document_part_, styles_part_
-
-    @pytest.fixture
-    def styles_part_get_fixture(self, document, document_part_, styles_part_):
-        document_part_.part_related_by.return_value = styles_part_
-        return document, document_part_, styles_part_
+    def styles_(self, request):
+        return instance_mock(request, Styles)
 
     @pytest.fixture
     def table_(self, request):
